@@ -255,8 +255,9 @@ group2 = gl.groups.create({"name": "group2", "path": "group2"})
 
 p_id = gl.groups.list(search="group2")[0].id
 group3 = gl.groups.create({"name": "group3", "path": "group3", "parent_id": p_id})
+group4 = gl.groups.create({"name": "group4", "path": "group4"})
 
-assert len(gl.groups.list()) == 3
+assert len(gl.groups.list()) == 4
 assert len(gl.groups.list(search="oup1")) == 1
 assert group3.parent_id == p_id
 assert group2.subgroups.list()[0].id == group3.id
@@ -266,6 +267,16 @@ group1.members.create({"access_level": gitlab.const.GUEST_ACCESS, "user_id": use
 
 group2.members.create({"access_level": gitlab.const.OWNER_ACCESS, "user_id": user2.id})
 
+group4.share(group1.id, gitlab.const.DEVELOPER_ACCESS)
+group4.share(group2.id, gitlab.const.MAINTAINER_ACCESS)
+# Reload group4 to have updated shared_with_groups
+group4 = gl.groups.get(group4.id)
+assert len(group4.shared_with_groups) == 2
+group4.unshare(group1.id)
+# Reload group4 to have updated shared_with_groups
+group4 = gl.groups.get(group4.id)
+assert len(group4.shared_with_groups) == 1
+
 # User memberships (admin only)
 memberships1 = user1.memberships.list()
 assert len(memberships1) == 1
@@ -356,17 +367,6 @@ assert gm1.state == "closed"
 assert len(gm1.issues()) == 0
 assert len(gm1.merge_requests()) == 0
 
-# group variables
-group1.variables.create({"key": "foo", "value": "bar"})
-g_v = group1.variables.get("foo")
-assert g_v.value == "bar"
-g_v.value = "baz"
-g_v.save()
-g_v = group1.variables.get("foo")
-assert g_v.value == "baz"
-assert len(group1.variables.list()) == 1
-g_v.delete()
-assert len(group1.variables.list()) == 0
 
 # group labels
 # group1.labels.create({"name": "foo", "description": "bar", "color": "#112233"})
@@ -419,7 +419,7 @@ gr1_project = gl.projects.create({"name": "gr1_project", "namespace_id": group1.
 gr2_project = gl.projects.create({"name": "gr2_project", "namespace_id": group2.id})
 sudo_project = gl.projects.create({"name": "sudo_project"}, sudo=user1.name)
 
-assert len(gl.projects.list(owned=True)) == 2
+assert len(gl.projects.list(owned=True)) == 3
 assert len(gl.projects.list(search="admin")) == 1
 assert len(gl.projects.list(as_list=False)) == 4
 
@@ -690,7 +690,12 @@ deploy_token_group = gl.groups.create(
 
 # Remove once https://gitlab.com/gitlab-org/gitlab/-/issues/211878 is fixed
 deploy_token = deploy_token_group.deploytokens.create(
-    {"name": "foo", "username": "", "expires_at": "", "scopes": ["read_repository"],}
+    {
+        "name": "foo",
+        "username": "",
+        "expires_at": "",
+        "scopes": ["read_repository"],
+    }
 )
 
 assert len(deploy_token_group.deploytokens.list()) == 1
@@ -771,6 +776,11 @@ assert events
 event = issue1.resourcelabelevents.get(events[0].id)
 assert event
 
+# issue milestones
+milestones = issue1.resourcemilestoneevents.list()
+assert milestones
+milestone = issue1.resourcemilestoneevents.get(milestones[0].id)
+assert milestone
 
 size = len(issue1.discussions.list())
 discussion = issue1.discussions.create({"body": "Discussion body"})
@@ -835,14 +845,6 @@ tr1 = admin_project.triggers.create({"description": "trigger1"})
 assert len(admin_project.triggers.list()) == 1
 tr1.delete()
 
-# variables
-v1 = admin_project.variables.create({"key": "key1", "value": "value1"})
-assert len(admin_project.variables.list()) == 1
-v1.value = "new_value1"
-v1.save()
-v1 = admin_project.variables.get(v1.key)
-assert v1.value == "new_value1"
-v1.delete()
 
 # branches and merges
 to_merge = admin_project.branches.create({"branch": "branch1", "ref": "master"})
@@ -880,6 +882,14 @@ assert events
 event = mr.resourcelabelevents.get(events[0].id)
 assert event
 
+# mr milestone events
+mr.milestone_id = m1.id
+mr.save()
+milestones = mr.resourcemilestoneevents.list()
+assert milestones
+milestone = mr.resourcemilestoneevents.get(milestones[0].id)
+assert milestone
+
 # rebasing
 assert mr.rebase()
 
